@@ -130,7 +130,7 @@ import qualified System.Console.Terminal.Size as Console
 import System.IO
 import System.IO.Unsafe (unsafePerformIO)
 import Text.Read
-import Data.List
+import Data.List (intercalate, nubBy)
 #ifndef mingw32_HOST_OS
 import System.Posix.Signals
 import System.Posix.Signals.Exts
